@@ -5,8 +5,6 @@
 #include "modules/brightness/brightness.h"
 #include "util/stringUtils.h"
 
-#define FF_BRIGHTNESS_NUM_FORMAT_ARGS 5
-
 void ffPrintBrightness(FFBrightnessOptions* options)
 {
     FF_LIST_AUTO_DESTROY result = ffListCreate(sizeof(FFBrightnessResult));
@@ -25,56 +23,83 @@ void ffPrintBrightness(FFBrightnessOptions* options)
         return;
     }
 
+    FFPercentageTypeFlags percentType = options->percent.type == 0 ? instance.config.display.percentType : options->percent.type;
+
+    if (options->compact)
+    {
+        FF_STRBUF_AUTO_DESTROY str = ffStrbufCreate();
+
+        FF_LIST_FOR_EACH(FFBrightnessResult, item, result)
+        {
+            if(str.length > 0)
+                ffStrbufAppendC(&str, ' ');
+
+            const double percent = (item->current - item->min) / (item->max - item->min) * 100;
+            ffPercentAppendNum(&str, percent, options->percent, false, &options->moduleArgs);
+        }
+
+        ffPrintLogoAndKey(FF_BRIGHTNESS_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT);
+        ffStrbufPutTo(&str, stdout);
+        return;
+    }
+
     FF_STRBUF_AUTO_DESTROY key = ffStrbufCreate();
 
     uint32_t index = 0;
     FF_LIST_FOR_EACH(FFBrightnessResult, item, result)
     {
-        if(options->moduleArgs.key.length == 0)
+        if (options->moduleArgs.key.length == 0)
         {
             ffStrbufAppendF(&key, "%s (%s)", FF_BRIGHTNESS_MODULE_NAME, item->name.chars);
         }
         else
         {
             uint32_t moduleIndex = result.length == 1 ? 0 : index + 1;
-            FF_PARSE_FORMAT_STRING_CHECKED(&key, &options->moduleArgs.key, 2, ((FFformatarg[]){
-                {FF_FORMAT_ARG_TYPE_UINT, &moduleIndex},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &item->name}
+            FF_PARSE_FORMAT_STRING_CHECKED(&key, &options->moduleArgs.key, ((FFformatarg[]) {
+                FF_FORMAT_ARG(moduleIndex, "index"),
+                FF_FORMAT_ARG(item->name, "name"),
+                FF_FORMAT_ARG(options->moduleArgs.keyIcon, "icon"),
             }));
         }
 
         const double percent = (item->current - item->min) / (item->max - item->min) * 100;
 
-        if(options->moduleArgs.outputFormat.length == 0)
+        if (options->moduleArgs.outputFormat.length == 0)
         {
             FF_STRBUF_AUTO_DESTROY str = ffStrbufCreate();
             ffPrintLogoAndKey(key.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_NO_CUSTOM_KEY);
 
-            if (instance.config.display.percentType & FF_PERCENTAGE_TYPE_BAR_BIT)
+            if (percentType & FF_PERCENTAGE_TYPE_BAR_BIT)
             {
-                ffPercentAppendBar(&str, percent, options->percent);
+                ffPercentAppendBar(&str, percent, options->percent, &options->moduleArgs);
             }
 
-            if(instance.config.display.percentType & FF_PERCENTAGE_TYPE_NUM_BIT)
+            if (percentType & FF_PERCENTAGE_TYPE_NUM_BIT)
             {
                 if(str.length > 0)
                     ffStrbufAppendC(&str, ' ');
 
-                ffPercentAppendNum(&str, percent, options->percent, str.length > 0);
+                ffPercentAppendNum(&str, percent, options->percent, str.length > 0, &options->moduleArgs);
             }
 
             ffStrbufPutTo(&str, stdout);
         }
         else
         {
-            FF_STRBUF_AUTO_DESTROY valueStr = ffStrbufCreate();
-            ffPercentAppendNum(&valueStr, percent, options->percent, false);
-            FF_PRINT_FORMAT_CHECKED(key.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_NO_CUSTOM_KEY, FF_BRIGHTNESS_NUM_FORMAT_ARGS, ((FFformatarg[]) {
-                {FF_FORMAT_ARG_TYPE_STRBUF, &valueStr},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &item->name},
-                {FF_FORMAT_ARG_TYPE_DOUBLE, &item->max},
-                {FF_FORMAT_ARG_TYPE_DOUBLE, &item->min},
-                {FF_FORMAT_ARG_TYPE_DOUBLE, &item->current},
+            FF_STRBUF_AUTO_DESTROY valueNum = ffStrbufCreate();
+            if (percentType & FF_PERCENTAGE_TYPE_NUM_BIT)
+                ffPercentAppendNum(&valueNum, percent, options->percent, false, &options->moduleArgs);
+            FF_STRBUF_AUTO_DESTROY valueBar = ffStrbufCreate();
+            if (percentType & FF_PERCENTAGE_TYPE_BAR_BIT)
+                ffPercentAppendBar(&valueBar, percent, options->percent, &options->moduleArgs);
+
+            FF_PRINT_FORMAT_CHECKED(key.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_NO_CUSTOM_KEY, ((FFformatarg[]) {
+                FF_FORMAT_ARG(valueNum, "percentage"),
+                FF_FORMAT_ARG(item->name, "name"),
+                FF_FORMAT_ARG(item->max, "max"),
+                FF_FORMAT_ARG(item->min, "min"),
+                FF_FORMAT_ARG(item->current, "current"),
+                FF_FORMAT_ARG(valueBar, "percentage-bar"),
             }));
         }
 
@@ -97,6 +122,12 @@ bool ffParseBrightnessCommandOptions(FFBrightnessOptions* options, const char* k
         return true;
     }
 
+    if (ffStrEqualsIgnCase(subKey, "compact"))
+    {
+        options->compact = ffOptionParseBoolean(value);
+        return true;
+    }
+
     if (ffPercentParseCommandOptions(key, subKey, value, &options->percent))
         return true;
 
@@ -122,6 +153,12 @@ void ffParseBrightnessJsonObject(FFBrightnessOptions* options, yyjson_val* modul
             continue;
         }
 
+        if (ffStrEqualsIgnCase(key, "compact"))
+        {
+            options->compact = (uint32_t) yyjson_get_bool(val);
+            continue;
+        }
+
         if (ffPercentParseJsonObject(key, val, &options->percent))
             continue;
 
@@ -140,6 +177,9 @@ void ffGenerateBrightnessJsonConfig(FFBrightnessOptions* options, yyjson_mut_doc
         yyjson_mut_obj_add_uint(doc, module, "ddcciSleep", options->ddcciSleep);
 
     ffPercentGenerateJsonConfig(doc, module, defaultOptions.percent, options->percent);
+
+    if (defaultOptions.compact != options->compact)
+        yyjson_mut_obj_add_bool(doc, module, "compact", options->compact);
 }
 
 void ffGenerateBrightnessJsonResult(FF_MAYBE_UNUSED FFBrightnessOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
@@ -154,12 +194,6 @@ void ffGenerateBrightnessJsonResult(FF_MAYBE_UNUSED FFBrightnessOptions* options
         return;
     }
 
-    if(result.length == 0)
-    {
-        yyjson_mut_obj_add_str(doc, module, "error", "No result is detected.");
-        return;
-    }
-
     yyjson_mut_val* arr = yyjson_mut_arr(doc);
     yyjson_mut_obj_add_val(doc, module, "result", arr);
 
@@ -178,34 +212,32 @@ void ffGenerateBrightnessJsonResult(FF_MAYBE_UNUSED FFBrightnessOptions* options
     }
 }
 
-void ffPrintBrightnessHelpFormat(void)
-{
-    FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_BRIGHTNESS_MODULE_NAME, "{1}", FF_BRIGHTNESS_NUM_FORMAT_ARGS, ((const char* []) {
-        "Screen brightness (percentage)",
-        "Screen name",
-        "Maximum brightness value",
-        "Minimum brightness value",
-        "Current brightness value",
-    }));
-}
+static FFModuleBaseInfo ffModuleInfo = {
+    .name = FF_BRIGHTNESS_MODULE_NAME,
+    .description = "Print current brightness level of your monitors",
+    .parseCommandOptions = (void*) ffParseBrightnessCommandOptions,
+    .parseJsonObject = (void*) ffParseBrightnessJsonObject,
+    .printModule = (void*) ffPrintBrightness,
+    .generateJsonResult = (void*) ffGenerateBrightnessJsonResult,
+    .generateJsonConfig = (void*) ffGenerateBrightnessJsonConfig,
+    .formatArgs = FF_FORMAT_ARG_LIST(((FFModuleFormatArg[]) {
+        {"Screen brightness (percentage num)", "percentage"},
+        {"Screen name", "name"},
+        {"Maximum brightness value", "max"},
+        {"Minimum brightness value", "min"},
+        {"Current brightness value", "current"},
+        {"Screen brightness (percentage bar)", "percentage-bar"},
+    }))
+};
 
 void ffInitBrightnessOptions(FFBrightnessOptions* options)
 {
-    ffOptionInitModuleBaseInfo(
-        &options->moduleInfo,
-        FF_BRIGHTNESS_MODULE_NAME,
-        "Print current brightness level of your monitors",
-        ffParseBrightnessCommandOptions,
-        ffParseBrightnessJsonObject,
-        ffPrintBrightness,
-        ffGenerateBrightnessJsonResult,
-        ffPrintBrightnessHelpFormat,
-        ffGenerateBrightnessJsonConfig
-    );
-    ffOptionInitModuleArg(&options->moduleArgs);
+    options->moduleInfo = ffModuleInfo;
+    ffOptionInitModuleArg(&options->moduleArgs, "󰯪");
 
     options->ddcciSleep = 10;
-    options->percent = (FFColorRangeConfig) { 100, 100 };
+    options->percent = (FFPercentageModuleConfig) { 100, 100, 0 };
+    options->compact = false;
 }
 
 void ffDestroyBrightnessOptions(FFBrightnessOptions* options)
